# streamlit_3d

3d model viewer

## Installation instructions 

```sh
pip install streamlit_3d
```

## Usage instructions

```python
import streamlit as st

from streamlit_3d import streamlit_3d

value = streamlit_3d()

st.write(value)
